@@ -1,6 +1,9 @@
 /***************************************************************************
  *   Copyright (C) 2004-2005 by Enrico Ros <eros.kde@email.it>             *
  *   Copyright (C) 2004-2008 by Albert Astals Cid <aacid@kde.org>          *
+ *   Copyright (C) 2017      Klarälvdalens Datakonsult AB, a KDAB Group    *
+ *                           company, info@kdab.com. Work sponsored by the *
+ *                           LiMux project of the city of Munich           *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -45,6 +48,7 @@ class DocumentViewport;
 class EmbeddedFile;
 class ExportFormat;
 class FontInfo;
+class FormField;
 class FormFieldText;
 class FormFieldButton;
 class FormFieldChoice;
@@ -302,7 +306,7 @@ class OKULARCORE_EXPORT Document : public QObject
          * Sets the list of visible page rectangles.
          * @see VisiblePageRect
          */
-        void setVisiblePageRects( const QVector< VisiblePageRect * > & visiblePageRects, DocumentObserver *excludeObserver = 0 );
+        void setVisiblePageRects( const QVector< VisiblePageRect * > & visiblePageRects, DocumentObserver *excludeObserver = nullptr );
 
         /**
          * Returns the list of visible page rectangles.
@@ -419,7 +423,7 @@ class OKULARCORE_EXPORT Document : public QObject
          * @param excludeObserver The observer ids which shouldn't be effected by this change.
          * @param smoothMove Whether the move shall be animated smoothly.
          */
-        void setViewportPage( int page, DocumentObserver *excludeObserver = 0, bool smoothMove = false );
+        void setViewportPage( int page, DocumentObserver *excludeObserver = nullptr, bool smoothMove = false );
 
         /**
          * Sets the current document viewport to the given @p viewport.
@@ -427,7 +431,7 @@ class OKULARCORE_EXPORT Document : public QObject
          * @param excludeObserver The observer which shouldn't be effected by this change.
          * @param smoothMove Whether the move shall be animated smoothly.
          */
-        void setViewport( const DocumentViewport &viewport, DocumentObserver *excludeObserver = 0, bool smoothMove = false );
+        void setViewport( const DocumentViewport &viewport, DocumentObserver *excludeObserver = nullptr, bool smoothMove = false );
 
         /**
          * Sets the current document viewport to the next viewport in the
@@ -456,7 +460,7 @@ class OKULARCORE_EXPORT Document : public QObject
         /**
          * Sets the zoom for the current document.
          */
-        void setZoom( int factor, DocumentObserver *excludeObserver = 0 );
+        void setZoom( int factor, DocumentObserver *excludeObserver = nullptr );
 
         /**
          * Describes the possible options for the pixmap requests.
@@ -608,12 +612,13 @@ class OKULARCORE_EXPORT Document : public QObject
         /**
          * Describes how search ended
          */
+        // TODO remove EndOfDocumentReached when we break API
         enum SearchStatus
         {
             MatchFound,           ///< Any match was found
             NoMatchFound,         ///< No match was found
             SearchCancelled,      ///< The search was cancelled
-            EndOfDocumentReached  ///< The end of document was reached without any match @since 0.20 (KDE 4.14)
+            EndOfDocumentReached  ///< This is not ever emitted since 1.3. The end of document was reached without any match @since 0.20 (KDE 4.14)
         };
 
         /**
@@ -736,6 +741,48 @@ class OKULARCORE_EXPORT Document : public QObject
          */
         KPluginMetaData generatorInfo() const;
 
+        /**
+         * Returns whether the generator supports hot-swapping the current file
+         * with another identical file
+         *
+         * @since 1.3
+         */
+        bool canSwapBackingFile() const;
+
+        /**
+         * Reload the document from a new location, without any visible effect
+         * to the user.
+         *
+         * The new file must be identical to the current one or, if the document
+         * has been modified (eg the user edited forms and annotations), the new
+         * document must have these changes too. For example, you can call
+         * saveChanges first to write changes to a file and then swapBackingFile
+         * to switch to the new location.
+         *
+         * @since 1.3
+         */
+        bool swapBackingFile( const QString &newFileName, const QUrl &url );
+
+        /**
+         * Same as swapBackingFile, but newFileName must be a .okular file.
+         *
+         * The new file must be identical to the current one or, if the document
+         * has been modified (eg the user edited forms and annotations), the new
+         * document must have these changes too. For example, you can call
+         * saveDocumentArchive first to write changes to a file and then
+         * swapBackingFileArchive to switch to the new location.
+         *
+         * @since 1.3
+         */
+        bool swapBackingFileArchive( const QString &newFileName, const QUrl &url );
+
+        /**
+         * Sets the history to be clean
+         *
+         * @since 1.3
+         */
+        void setHistoryClean( bool clean );
+
         /**
          * Saving capabilities. Their availability varies according to the
          * underlying generator and/or the document type.
@@ -821,6 +868,15 @@ class OKULARCORE_EXPORT Document : public QObject
          */
         bool saveDocumentArchive( const QString &fileName );
 
+        /**
+         * Extract the document file from the current archive.
+         *
+         * @warning This function only works if the current file is a document archive
+         *
+         * @since 1.3
+         */
+        bool extractArchivedFile( const QString &destFileName );
+
         /**
          * Asks the generator to dynamically generate a SourceReference for a given
          * page number and absolute X and Y position on this page.
@@ -856,6 +912,25 @@ class OKULARCORE_EXPORT Document : public QObject
         */
         void walletDataForFile( const QString &fileName, QString *walletName, QString *walletFolder, QString *walletKey ) const;
 
+        /**
+         * Since version 0.21, okular does not allow editing annotations and
+         * form data if they are stored in the docdata directory (like older
+         * okular versions did by default).
+         * If this flag is set, then annotations and forms cannot be edited.
+         *
+         * @since 1.3
+        */
+        bool isDocdataMigrationNeeded() const;
+
+        /**
+         * Delete annotations and form data from the docdata folder. Call it if
+         * isDocdataMigrationNeeded() was true and you've just saved them to an
+         * external file.
+         *
+         * @since 1.3
+        */
+        void docdataMigrationDone();
+
         /**
          * Returns the model for rendering layers (NULL if the document has no layers)
          *
@@ -1065,6 +1140,12 @@ class OKULARCORE_EXPORT Document : public QObject
          */
         void canRedoChanged( bool redoAvailable );
 
+        /**
+         * This signal is emmitted whenever the undo history is clean (i.e. the same status the last time it was saved)
+         * @since 1.3
+         */
+        void undoHistoryCleanChanged( bool clean );
+
         /**
          * This signal is emitted whenever an rendition action is triggered and the UI should process it.
          *
@@ -1112,6 +1193,13 @@ class OKULARCORE_EXPORT Document : public QObject
          * @since 0.17 (KDE 4.11)
          */
         void formButtonsChangedByUndoRedo( int page, const QList< Okular::FormFieldButton* > & formButtons );
+
+        /**
+         * This signal is emmitted whenever a FormField was changed programatically and the
+         * according widget should be updated.
+         * @since 1.4
+         */
+        void refreshFormWidget( Okular::FormField *field );
     private:
         /// @cond PRIVATE
         friend class DocumentPrivate;
