@@ -29,23 +29,23 @@ class PluckerGenerator : public Okular::Generator
         virtual ~PluckerGenerator();
 
         // [INHERITED] load a document and fill up the pagesVector
-        bool loadDocument( const QString & fileName, QVector<Okular::Page*> & pagesVector ) Q_DECL_OVERRIDE;
+        bool loadDocument( const QString & fileName, QVector<Okular::Page*> & pagesVector ) override;
 
         // [INHERITED] document information
-        Okular::DocumentInfo generateDocumentInfo( const QSet<Okular::DocumentInfo::Key> &keys ) const Q_DECL_OVERRIDE;
+        Okular::DocumentInfo generateDocumentInfo( const QSet<Okular::DocumentInfo::Key> &keys ) const override;
         
         // [INHERITED] perform actions on document / pages
-        QImage image( Okular::PixmapRequest *request ) Q_DECL_OVERRIDE;
+        QImage image( Okular::PixmapRequest *request ) override;
 
         // [INHERITED] text exporting
-        Okular::ExportFormat::List exportFormats() const Q_DECL_OVERRIDE;
-        bool exportTo( const QString &fileName, const Okular::ExportFormat &format ) Q_DECL_OVERRIDE;
+        Okular::ExportFormat::List exportFormats() const override;
+        bool exportTo( const QString &fileName, const Okular::ExportFormat &format ) override;
 
         // [INHERITED] print document using already configured kprinter
-        bool print( QPrinter& printer ) Q_DECL_OVERRIDE;
+        bool print( QPrinter& printer ) override;
 
     protected:
-        bool doCloseDocument() Q_DECL_OVERRIDE;
+        bool doCloseDocument() override;
 
     private:
       QList<QTextDocument*> mPages;
