@@ -1,5 +1,8 @@
 /***************************************************************************
  *   Copyright (C) 2004-2005 by Enrico Ros <eros.kde@email.it>             *
+ *   Copyright (C) 2017    Klarälvdalens Datakonsult AB, a KDAB Group      *
+ *                         company, info@kdab.com. Work sponsored by the   *
+ *                         LiMux project of the city of Munich             *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -25,7 +28,7 @@
 #include <kactioncollection.h>
 #include <kcolorscheme.h>
 #include <kiconloader.h>
-#include <klocale.h>
+#include <KLocalizedString>
 
 // system includes
 #include <math.h>
@@ -51,9 +54,7 @@ PageViewItem::PageViewItem( const Okular::Page * page )
 
 PageViewItem::~PageViewItem()
 {
-    QHash<int, FormWidgetIface*>::iterator it = m_formWidgets.begin(), itEnd = m_formWidgets.end();
-    for ( ; it != itEnd; ++it )
-        delete *it;
+    qDeleteAll( m_formWidgets );
     qDeleteAll( m_videoWidgets );
 }
 
@@ -122,7 +123,7 @@ bool PageViewItem::isVisible() const
     return m_visible;
 }
 
-QHash<int, FormWidgetIface*>& PageViewItem::formWidgets()
+QSet<FormWidgetIface*>& PageViewItem::formWidgets()
 {
     return m_formWidgets;
 }
@@ -163,7 +164,7 @@ void PageViewItem::moveTo( int x, int y )
     m_croppedGeometry.moveTop( y );
     m_uncroppedGeometry.moveLeft( qRound( x - m_crop.left * m_uncroppedGeometry.width() ) );
     m_uncroppedGeometry.moveTop( qRound( y - m_crop.top * m_uncroppedGeometry.height() ) );
-    QHash<int, FormWidgetIface*>::iterator it = m_formWidgets.begin(), itEnd = m_formWidgets.end();
+    QSet<FormWidgetIface*>::iterator it = m_formWidgets.begin(), itEnd = m_formWidgets.end();
     for ( ; it != itEnd; ++it )
     {
         Okular::NormalizedRect r = (*it)->rect();
@@ -200,10 +201,11 @@ bool PageViewItem::setFormWidgetsVisible( bool visible )
         return false;
 
     bool somehadfocus = false;
-    QHash<int, FormWidgetIface*>::iterator it = m_formWidgets.begin(), itEnd = m_formWidgets.end();
+    QSet<FormWidgetIface*>::iterator it = m_formWidgets.begin(), itEnd = m_formWidgets.end();
     for ( ; it != itEnd; ++it )
     {
-        bool hadfocus = (*it)->setVisibility( visible && (*it)->formField()->isVisible() );
+        bool hadfocus = (*it)->setVisibility( visible && (*it)->formField()->isVisible() &&
+                                              !(*it)->formField()->isReadOnly() );
         somehadfocus = somehadfocus || hadfocus;
     }
     return somehadfocus;
@@ -213,7 +215,7 @@ void PageViewItem::reloadFormWidgetsState()
 {
     foreach(FormWidgetIface *fwi, m_formWidgets)
     {
-        fwi->setVisibility( fwi->formField()->isVisible() );
+        fwi->setVisibility( fwi->formField()->isVisible() && !fwi->formField()->isReadOnly() );
     }
 }
 
@@ -222,10 +224,10 @@ void PageViewItem::reloadFormWidgetsState()
 /*********************/
 
 PageViewMessage::PageViewMessage( QWidget * parent )
-    : QWidget( parent ), m_timer( 0 )
+    : QWidget( parent ), m_timer( nullptr )
     , m_lineSpacing( 0 )
 {
-    setObjectName( QLatin1String( "pageViewMessage" ) );
+    setObjectName( QStringLiteral( "pageViewMessage" ) );
     setFocusPolicy( Qt::NoFocus );
     QPalette pal = palette();
     pal.setColor( QPalette::Active, QPalette::Window, QApplication::palette().color( QPalette::Active, QPalette::Window ) );
@@ -261,19 +263,19 @@ void PageViewMessage::display( const QString & message, const QString & details,
         switch ( icon )
         {
             case Annotation:
-                m_symbol = SmallIcon( "draw-freehand" );
+                m_symbol = SmallIcon( QStringLiteral("draw-freehand") );
                 break;
             case Find:
-                m_symbol = SmallIcon( "zoom-original" );
+                m_symbol = SmallIcon( QStringLiteral("zoom-original") );
                 break;
             case Error:
-                m_symbol = SmallIcon( "dialog-error" );
+                m_symbol = SmallIcon( QStringLiteral("dialog-error") );
                 break;
             case Warning:
-                m_symbol = SmallIcon( "dialog-warning" );
+                m_symbol = SmallIcon( QStringLiteral("dialog-warning") );
                 break;
             default:
-                m_symbol = SmallIcon( "dialog-information" );
+                m_symbol = SmallIcon( QStringLiteral("dialog-information") );
                 break;
         }
 
@@ -291,7 +293,7 @@ void PageViewMessage::display( const QString & message, const QString & details,
         {
             m_timer = new QTimer( this );
             m_timer->setSingleShot( true );
-            connect( m_timer, SIGNAL(timeout()), SLOT(hide()) );
+            connect(m_timer, &QTimer::timeout, this, &PageViewMessage::hide);
         }
         m_timer->start( durationMs );
     } else if ( m_timer )
@@ -449,7 +451,7 @@ ToolBarButton::ToolBarButton( QWidget * parent, const AnnotationToolItem &item )
     // if accel is set display it along name
     QString accelString = shortcut().toString( QKeySequence::NativeText );
     if ( !accelString.isEmpty() )
-        setToolTip( QString("%1 [%2]").arg( item.text ).arg( accelString ) );
+        setToolTip( QStringLiteral("%1 [%2]").arg( item.text, accelString ) );
     else
         setToolTip( item.text );
 }
@@ -508,13 +510,13 @@ PageViewToolBar::PageViewToolBar( PageView * parent, QWidget * anchorWidget )
 
     // create the animation timer
     d->animTimer = new QTimer( this );
-    connect( d->animTimer, SIGNAL(timeout()), this, SLOT(slotAnimate()) );
+    connect( d->animTimer, &QTimer::timeout, this, &PageViewToolBar::slotAnimate );
 
     // apply a filter to get notified when anchor changes geometry
     d->anchorWidget->installEventFilter( this );
 
     setContextMenuPolicy( Qt::ActionsContextMenu );
-    addAction( parent->actionCollection()->action( "options_configure_annotations" ) );
+    addAction( parent->actionCollection()->action( QStringLiteral("options_configure_annotations") ) );
 }
 
 PageViewToolBar::~PageViewToolBar()
@@ -539,8 +541,8 @@ void PageViewToolBar::setItems( const QLinkedList<AnnotationToolItem> &items )
     for ( ; it != end; ++it )
     {
         ToolBarButton * button = new ToolBarButton( this, *it );
-        connect( button, SIGNAL(clicked()), this, SLOT(slotButtonClicked()) );
-        connect( button, SIGNAL(buttonDoubleClicked(int)), this, SIGNAL(buttonDoubleClicked(int)) );
+        connect(button, &ToolBarButton::clicked, this, &PageViewToolBar::slotButtonClicked);
+        connect(button, &ToolBarButton::buttonDoubleClicked, this, &PageViewToolBar::buttonDoubleClicked);
         d->buttons.append( button );
     }
 
@@ -595,7 +597,7 @@ void PageViewToolBar::hideAndDestroy()
 
 void PageViewToolBar::selectButton( int id )
 {
-    ToolBarButton * button = 0;
+    ToolBarButton * button = nullptr;
     if ( id >= 0 && id < d->buttons.count() )
         button = *(d->buttons.begin() + id);
     else
@@ -943,4 +945,4 @@ void PageViewToolBar::setTextToolsEnabled( bool on )
             (*it)->setEnabled( on );
 }
 
-#include "pageviewutils.moc"
+#include "moc_pageviewutils.cpp"
